@@ -12,8 +12,8 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK2NConstantCache,
         repeat_step = false)
-    @unpack t, dt, u, f, p = integrator
-    @unpack A2end, B1, B2end, c2end = cache
+    (; t, dt, u, f, p) = integrator
+    (; A2end, B1, B2end, c2end) = cache
 
     # u1
     tmp = dt * integrator.fsalfirst
@@ -36,7 +36,7 @@ end
 get_fsalfirstlast(cache::LowStorageRK2NCache, u) = (nothing, nothing)
 
 function initialize!(integrator, cache::LowStorageRK2NCache)
-    @unpack k, tmp, williamson_condition = cache
+    (; k, tmp, williamson_condition) = cache
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
     integrator.k[1] = k
@@ -45,25 +45,25 @@ function initialize!(integrator, cache::LowStorageRK2NCache)
 end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK2NCache, repeat_step = false)
-    @unpack t, dt, u, f, p = integrator
-    @unpack k, tmp, williamson_condition, stage_limiter!, step_limiter!, thread = cache
-    @unpack A2end, B1, B2end, c2end = cache.tab
+    (; t, dt, u, f, p) = integrator
+    (; k, tmp, williamson_condition, stage_limiter!, step_limiter!, thread) = cache
+    (; A2end, B1, B2end, c2end) = cache.tab
 
     # u1
     f(k, u, p, t)
     OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
-    @.. broadcast=false thread=thread tmp=dt * k
-    @.. broadcast=false thread=thread u=u + B1 * tmp
+    @.. broadcast=false thread=thread tmp=dt*k
+    @.. broadcast=false thread=thread u=u+B1*tmp
     # other stages
     for i in eachindex(A2end)
         if williamson_condition
             f(ArrayFuse(tmp, u, (A2end[i], dt, B2end[i])), u, p, t + c2end[i] * dt)
         else
-            @.. broadcast=false thread=thread tmp=A2end[i] * tmp
+            @.. broadcast=false thread=thread tmp=A2end[i]*tmp
             stage_limiter!(u, integrator, p, t + c2end[i] * dt)
             f(k, u, p, t + c2end[i] * dt)
-            @.. broadcast=false thread=thread tmp=tmp + dt * k
-            @.. broadcast=false thread=thread u=u + B2end[i] * tmp
+            @.. broadcast=false thread=thread tmp=tmp+dt*k
+            @.. broadcast=false thread=thread u=u+B2end[i]*tmp
         end
         OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
     end
@@ -85,8 +85,8 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK2CConstantCache,
         repeat_step = false)
-    @unpack t, dt, u, f, p = integrator
-    @unpack A2end, B1, B2end, c2end = cache
+    (; t, dt, u, f, p) = integrator
+    (; A2end, B1, B2end, c2end) = cache
 
     # u1
     k = integrator.fsalfirst = f(u, p, t)
@@ -106,7 +106,7 @@ end
 end
 
 function initialize!(integrator, cache::LowStorageRK2CCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
@@ -116,20 +116,20 @@ function initialize!(integrator, cache::LowStorageRK2CCache)
 end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK2CCache, repeat_step = false)
-    @unpack t, dt, u, f, p = integrator
-    @unpack k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack A2end, B1, B2end, c2end = cache.tab
+    (; t, dt, u, f, p) = integrator
+    (; k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread) = cache
+    (; A2end, B1, B2end, c2end) = cache.tab
 
     # u1
     @.. broadcast=false thread=thread k=integrator.fsalfirst
-    @.. broadcast=false thread=thread u=u + B1 * dt * k
+    @.. broadcast=false thread=thread u=u+B1*dt*k
 
     # other stages
     for i in eachindex(A2end)
-        @.. broadcast=false thread=thread tmp=u + A2end[i] * dt * k
+        @.. broadcast=false thread=thread tmp=u+A2end[i]*dt*k
         f(k, tmp, p, t + c2end[i] * dt)
         OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
-        @.. broadcast=false thread=thread u=u + B2end[i] * dt * k
+        @.. broadcast=false thread=thread u=u+B2end[i]*dt*k
     end
     step_limiter!(u, integrator, p, t + dt)
     f(k, u, p, t + dt)
@@ -150,8 +150,8 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK3SConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end) = cache
 
     # u1
     tmp = u
@@ -172,7 +172,7 @@ end
 end
 
 function initialize!(integrator, cache::LowStorageRK3SCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
@@ -182,22 +182,22 @@ function initialize!(integrator, cache::LowStorageRK3SCache)
 end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK3SCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread) = cache
+    (; γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end) = cache.tab
 
     # u1
     @.. broadcast=false thread=thread tmp=u
-    @.. broadcast=false thread=thread u=tmp + β1 * dt * integrator.fsalfirst
+    @.. broadcast=false thread=thread u=tmp+β1*dt*integrator.fsalfirst
 
     # other stages
     for i in eachindex(γ12end)
         f(k, u, p, t + c2end[i] * dt)
         OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
-        @.. broadcast=false thread=thread tmp=tmp + δ2end[i] * u
-        @.. broadcast=false thread=thread u=γ12end[i] * u + γ22end[i] * tmp +
-                                            γ32end[i] * uprev +
-                                            β2end[i] * dt * k
+        @.. broadcast=false thread=thread tmp=tmp+δ2end[i]*u
+        @.. broadcast=false thread=thread u=γ12end[i]*u+γ22end[i]*tmp+
+                                            γ32end[i]*uprev+
+                                            β2end[i]*dt*k
     end
 
     step_limiter!(u, integrator, p, t + dt)
@@ -219,8 +219,8 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK3SpConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end, bhat1, bhat2end = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end, bhat1, bhat2end) = cache
 
     # u1
     integrator.fsalfirst = f(uprev, p, t)
@@ -228,6 +228,8 @@ end
     integrator.k[1] = integrator.fsalfirst
     tmp = uprev
     u = tmp + β1 * dt * integrator.fsalfirst
+    # Initialize utilde for JET
+    utilde = u
     if integrator.opts.adaptive
         utilde = bhat1 * dt * integrator.fsalfirst
     end
@@ -253,7 +255,7 @@ end
 end
 
 function initialize!(integrator, cache::LowStorageRK3SpCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
@@ -261,17 +263,17 @@ function initialize!(integrator, cache::LowStorageRK3SpCache)
 end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK3SpCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack k, tmp, utilde, atmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end, bhat1, bhat2end = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; k, tmp, utilde, atmp, stage_limiter!, step_limiter!, thread) = cache
+    (; γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end, bhat1, bhat2end) = cache.tab
 
     # u1
     f(integrator.fsalfirst, uprev, p, t)
     OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
     @.. broadcast=false thread=thread tmp=uprev
-    @.. broadcast=false thread=thread u=tmp + β1 * dt * integrator.fsalfirst
+    @.. broadcast=false thread=thread u=tmp+β1*dt*integrator.fsalfirst
     if integrator.opts.adaptive
-        @.. broadcast=false thread=thread utilde=bhat1 * dt * integrator.fsalfirst
+        @.. broadcast=false thread=thread utilde=bhat1*dt*integrator.fsalfirst
     end
 
     # other stages
@@ -279,11 +281,11 @@ end
         stage_limiter!(u, integrator, p, t + c2end[i] * dt)
         f(k, u, p, t + c2end[i] * dt)
         OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
-        @.. broadcast=false thread=thread tmp=tmp + δ2end[i] * u
-        @.. broadcast=false thread=thread u=γ12end[i] * u + γ22end[i] * tmp +
-                                            γ32end[i] * uprev + β2end[i] * dt * k
+        @.. broadcast=false thread=thread tmp=tmp+δ2end[i]*u
+        @.. broadcast=false thread=thread u=γ12end[i]*u+γ22end[i]*tmp+
+                                            γ32end[i]*uprev+β2end[i]*dt*k
         if integrator.opts.adaptive
-            @.. broadcast=false thread=thread utilde=utilde + bhat2end[i] * dt * k
+            @.. broadcast=false thread=thread utilde=utilde+bhat2end[i]*dt*k
         end
     end
 
@@ -313,12 +315,14 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK3SpFSALConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end, bhat1, bhat2end, bhatfsal = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end, bhat1, bhat2end, bhatfsal) = cache
 
     # u1
     tmp = uprev
     u = tmp + β1 * dt * integrator.fsalfirst
+    # Initialize utilde for JET
+    utilde = u
     if integrator.opts.adaptive
         utilde = bhat1 * dt * integrator.fsalfirst
     end
@@ -351,7 +355,7 @@ end
 end
 
 function initialize!(integrator, cache::LowStorageRK3SpFSALCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 2
     resize!(integrator.k, integrator.kshortsize)
@@ -363,15 +367,16 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK3SpFSALCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack k, tmp, utilde, atmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack γ12end, γ22end, γ32end, δ2end, β1, β2end, c2end, bhat1, bhat2end, bhatfsal = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; k, tmp, utilde, atmp, stage_limiter!, step_limiter!, thread) = cache
+    (; γ12end, γ22end, γ32end, δ2end, β1, β2end,
+        c2end, bhat1, bhat2end, bhatfsal) = cache.tab
 
     # u1
     @.. broadcast=false thread=thread tmp=uprev
-    @.. broadcast=false thread=thread u=tmp + β1 * dt * integrator.fsalfirst
+    @.. broadcast=false thread=thread u=tmp+β1*dt*integrator.fsalfirst
     if integrator.opts.adaptive
-        @.. broadcast=false thread=thread utilde=bhat1 * dt * integrator.fsalfirst
+        @.. broadcast=false thread=thread utilde=bhat1*dt*integrator.fsalfirst
     end
 
     # other stages
@@ -379,11 +384,11 @@ end
         stage_limiter!(u, integrator, p, t + c2end[i] * dt)
         f(k, u, p, t + c2end[i] * dt)
         OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
-        @.. broadcast=false thread=thread tmp=tmp + δ2end[i] * u
-        @.. broadcast=false thread=thread u=γ12end[i] * u + γ22end[i] * tmp +
-                                            γ32end[i] * uprev + β2end[i] * dt * k
+        @.. broadcast=false thread=thread tmp=tmp+δ2end[i]*u
+        @.. broadcast=false thread=thread u=γ12end[i]*u+γ22end[i]*tmp+
+                                            γ32end[i]*uprev+β2end[i]*dt*k
         if integrator.opts.adaptive
-            @.. broadcast=false thread=thread utilde=utilde + bhat2end[i] * dt * k
+            @.. broadcast=false thread=thread utilde=utilde+bhat2end[i]*dt*k
         end
     end
 
@@ -395,7 +400,7 @@ end
     OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
 
     if integrator.opts.adaptive
-        @.. broadcast=false thread=thread utilde=utilde + bhatfsal * dt * k
+        @.. broadcast=false thread=thread utilde=utilde+bhatfsal*dt*k
         calculate_residuals!(atmp, utilde, uprev, u, integrator.opts.abstol,
             integrator.opts.reltol, integrator.opts.internalnorm, t,
             thread)
@@ -417,10 +422,12 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK2RPConstantCache,
         repeat_step = false)
-    @unpack t, dt, u, uprev, f, fsalfirst, p = integrator
-    @unpack Aᵢ, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ = cache
+    (; t, dt, u, uprev, f, fsalfirst, p) = integrator
+    (; Aᵢ, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ) = cache
 
     k = fsalfirst
+    # Initialize tmp for JET
+    tmp = uprev
     integrator.opts.adaptive && (tmp = zero(uprev))
 
     #stages 1 to s-1
@@ -450,7 +457,7 @@ end
 end
 
 function initialize!(integrator, cache::LowStorageRK2RPCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
@@ -460,9 +467,9 @@ function initialize!(integrator, cache::LowStorageRK2RPCache)
 end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK2RPCache, repeat_step = false)
-    @unpack t, dt, u, uprev, f, fsalfirst, p = integrator
-    @unpack k, gprev, tmp, atmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack Aᵢ, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ = cache.tab
+    (; t, dt, u, uprev, f, fsalfirst, p) = integrator
+    (; k, gprev, tmp, atmp, stage_limiter!, step_limiter!, thread) = cache
+    (; Aᵢ, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ) = cache.tab
 
     @.. broadcast=false thread=thread k=fsalfirst
     integrator.opts.adaptive && (@.. broadcast=false tmp=zero(uprev))
@@ -470,17 +477,17 @@ end
     #stages 1 to s-1
     for i in eachindex(Aᵢ)
         integrator.opts.adaptive &&
-            (@.. broadcast=false thread=thread tmp=tmp + (Bᵢ[i] - B̂ᵢ[i]) * dt * k)
-        @.. broadcast=false thread=thread gprev=u + Aᵢ[i] * dt * k
-        @.. broadcast=false thread=thread u=u + Bᵢ[i] * dt * k
+            (@.. broadcast=false thread=thread tmp=tmp+(Bᵢ[i]-B̂ᵢ[i])*dt*k)
+        @.. broadcast=false thread=thread gprev=u+Aᵢ[i]*dt*k
+        @.. broadcast=false thread=thread u=u+Bᵢ[i]*dt*k
         f(k, gprev, p, t + Cᵢ[i] * dt)
         OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
     end
 
     #last stage
     integrator.opts.adaptive &&
-        (@.. broadcast=false thread=thread tmp=tmp + (Bₗ - B̂ₗ) * dt * k)
-    @.. broadcast=false thread=thread u=u + Bₗ * dt * k
+        (@.. broadcast=false thread=thread tmp=tmp+(Bₗ-B̂ₗ)*dt*k)
+    @.. broadcast=false thread=thread u=u+Bₗ*dt*k
 
     #Error estimate
     if integrator.opts.adaptive
@@ -509,13 +516,15 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK3RPConstantCache,
         repeat_step = false)
-    @unpack t, dt, u, uprev, f, fsalfirst, p = integrator
-    @unpack Aᵢ₁, Aᵢ₂, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ = cache
+    (; t, dt, u, uprev, f, fsalfirst, p) = integrator
+    (; Aᵢ₁, Aᵢ₂, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ) = cache
 
     fᵢ₋₂ = zero(fsalfirst)
     k = fsalfirst
     uᵢ₋₁ = uprev
     uᵢ₋₂ = uprev
+    # Initialize tmp for JET
+    tmp = uprev
     integrator.opts.adaptive && (tmp = zero(uprev))
 
     #stages 1 to s-1
@@ -548,7 +557,7 @@ end
 end
 
 function initialize!(integrator, cache::LowStorageRK3RPCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
@@ -558,9 +567,9 @@ function initialize!(integrator, cache::LowStorageRK3RPCache)
 end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK3RPCache, repeat_step = false)
-    @unpack t, dt, u, uprev, f, fsalfirst, p = integrator
-    @unpack k, uᵢ₋₁, uᵢ₋₂, gprev, fᵢ₋₂, tmp, atmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack Aᵢ₁, Aᵢ₂, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ = cache.tab
+    (; t, dt, u, uprev, f, fsalfirst, p) = integrator
+    (; k, uᵢ₋₁, uᵢ₋₂, gprev, fᵢ₋₂, tmp, atmp, stage_limiter!, step_limiter!, thread) = cache
+    (; Aᵢ₁, Aᵢ₂, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ) = cache.tab
 
     @.. broadcast=false thread=thread fᵢ₋₂=zero(fsalfirst)
     @.. broadcast=false thread=thread k=fsalfirst
@@ -571,9 +580,9 @@ end
     #stages 1 to s-1
     for i in eachindex(Aᵢ₁)
         integrator.opts.adaptive &&
-            (@.. broadcast=false thread=thread tmp=tmp + (Bᵢ[i] - B̂ᵢ[i]) * dt * k)
-        @.. broadcast=false thread=thread gprev=uᵢ₋₂ + (Aᵢ₁[i] * k + Aᵢ₂[i] * fᵢ₋₂) * dt
-        @.. broadcast=false thread=thread u=u + Bᵢ[i] * dt * k
+            (@.. broadcast=false thread=thread tmp=tmp+(Bᵢ[i]-B̂ᵢ[i])*dt*k)
+        @.. broadcast=false thread=thread gprev=uᵢ₋₂+(Aᵢ₁[i]*k+Aᵢ₂[i]*fᵢ₋₂)*dt
+        @.. broadcast=false thread=thread u=u+Bᵢ[i]*dt*k
         @.. broadcast=false thread=thread fᵢ₋₂=k
         @.. broadcast=false thread=thread uᵢ₋₂=uᵢ₋₁
         @.. broadcast=false thread=thread uᵢ₋₁=u
@@ -583,8 +592,8 @@ end
 
     #last stage
     integrator.opts.adaptive &&
-        (@.. broadcast=false thread=thread tmp=tmp + (Bₗ - B̂ₗ) * dt * k)
-    @.. broadcast=false thread=thread u=u + Bₗ * dt * k
+        (@.. broadcast=false thread=thread tmp=tmp+(Bₗ-B̂ₗ)*dt*k)
+    @.. broadcast=false thread=thread u=u+Bₗ*dt*k
 
     step_limiter!(u, integrator, p, t + dt)
 
@@ -614,8 +623,8 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK4RPConstantCache,
         repeat_step = false)
-    @unpack t, dt, u, uprev, f, fsalfirst, p = integrator
-    @unpack Aᵢ₁, Aᵢ₂, Aᵢ₃, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ = cache
+    (; t, dt, u, uprev, f, fsalfirst, p) = integrator
+    (; Aᵢ₁, Aᵢ₂, Aᵢ₃, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ) = cache
 
     fᵢ₋₂ = zero(fsalfirst)
     fᵢ₋₃ = zero(fsalfirst)
@@ -623,6 +632,8 @@ end
     uᵢ₋₁ = uprev
     uᵢ₋₂ = uprev
     uᵢ₋₃ = uprev
+    # Initialize tmp for JET
+    tmp = uprev
     integrator.opts.adaptive && (tmp = zero(uprev))
 
     #stages 1 to s-1
@@ -657,7 +668,7 @@ end
 end
 
 function initialize!(integrator, cache::LowStorageRK4RPCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
@@ -667,9 +678,10 @@ function initialize!(integrator, cache::LowStorageRK4RPCache)
 end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK4RPCache, repeat_step = false)
-    @unpack t, dt, u, uprev, f, fsalfirst, p = integrator
-    @unpack k, uᵢ₋₁, uᵢ₋₂, uᵢ₋₃, gprev, fᵢ₋₂, fᵢ₋₃, tmp, atmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack Aᵢ₁, Aᵢ₂, Aᵢ₃, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ = cache.tab
+    (; t, dt, u, uprev, f, fsalfirst, p) = integrator
+    (; k, uᵢ₋₁, uᵢ₋₂, uᵢ₋₃, gprev, fᵢ₋₂, fᵢ₋₃, tmp, atmp,
+        stage_limiter!, step_limiter!, thread) = cache
+    (; Aᵢ₁, Aᵢ₂, Aᵢ₃, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ) = cache.tab
 
     @.. broadcast=false thread=thread fᵢ₋₂=zero(fsalfirst)
     @.. broadcast=false thread=thread fᵢ₋₃=zero(fsalfirst)
@@ -682,12 +694,12 @@ end
     #stages 1 to s-1
     for i in eachindex(Aᵢ₁)
         integrator.opts.adaptive &&
-            (@.. broadcast=false thread=thread tmp=tmp + (Bᵢ[i] - B̂ᵢ[i]) * dt * k)
-        @.. broadcast=false thread=thread gprev=uᵢ₋₃ +
-                                                (Aᵢ₁[i] * k + Aᵢ₂[i] * fᵢ₋₂ +
-                                                 Aᵢ₃[i] * fᵢ₋₃) *
-                                                dt
-        @.. broadcast=false thread=thread u=u + Bᵢ[i] * dt * k
+            (@.. broadcast=false thread=thread tmp=tmp+(Bᵢ[i]-B̂ᵢ[i])*dt*k)
+        @.. broadcast=false thread=thread gprev=uᵢ₋₃+
+        (Aᵢ₁[i]*k+Aᵢ₂[i]*fᵢ₋₂+
+         Aᵢ₃[i]*fᵢ₋₃)*
+        dt
+        @.. broadcast=false thread=thread u=u+Bᵢ[i]*dt*k
         @.. broadcast=false thread=thread fᵢ₋₃=fᵢ₋₂
         @.. broadcast=false thread=thread fᵢ₋₂=k
         @.. broadcast=false thread=thread uᵢ₋₃=uᵢ₋₂
@@ -699,8 +711,8 @@ end
 
     #last stage
     integrator.opts.adaptive &&
-        (@.. broadcast=false thread=thread tmp=tmp + (Bₗ - B̂ₗ) * dt * k)
-    @.. broadcast=false thread=thread u=u + Bₗ * dt * k
+        (@.. broadcast=false thread=thread tmp=tmp+(Bₗ-B̂ₗ)*dt*k)
+    @.. broadcast=false thread=thread u=u+Bₗ*dt*k
 
     step_limiter!(u, integrator, p, t + dt)
 
@@ -730,8 +742,8 @@ end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK5RPConstantCache,
         repeat_step = false)
-    @unpack t, dt, u, uprev, f, fsalfirst, p = integrator
-    @unpack Aᵢ₁, Aᵢ₂, Aᵢ₃, Aᵢ₄, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ = cache
+    (; t, dt, u, uprev, f, fsalfirst, p) = integrator
+    (; Aᵢ₁, Aᵢ₂, Aᵢ₃, Aᵢ₄, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ) = cache
 
     fᵢ₋₂ = zero(fsalfirst)
     fᵢ₋₃ = zero(fsalfirst)
@@ -741,6 +753,8 @@ end
     uᵢ₋₂ = uprev
     uᵢ₋₃ = uprev
     uᵢ₋₄ = uprev
+    # Initialize tmp for JET
+    tmp = uprev
     integrator.opts.adaptive && (tmp = zero(uprev))
 
     #stages 1 to s-1
@@ -777,7 +791,7 @@ end
 end
 
 function initialize!(integrator, cache::LowStorageRK5RPCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
@@ -787,9 +801,10 @@ function initialize!(integrator, cache::LowStorageRK5RPCache)
 end
 
 @muladd function perform_step!(integrator, cache::LowStorageRK5RPCache, repeat_step = false)
-    @unpack t, dt, u, uprev, f, fsalfirst, p = integrator
-    @unpack k, uᵢ₋₁, uᵢ₋₂, uᵢ₋₃, uᵢ₋₄, gprev, fᵢ₋₂, fᵢ₋₃, fᵢ₋₄, tmp, atmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack Aᵢ₁, Aᵢ₂, Aᵢ₃, Aᵢ₄, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ = cache.tab
+    (; t, dt, u, uprev, f, fsalfirst, p) = integrator
+    (; k, uᵢ₋₁, uᵢ₋₂, uᵢ₋₃, uᵢ₋₄, gprev, fᵢ₋₂, fᵢ₋₃, fᵢ₋₄, tmp,
+        atmp, stage_limiter!, step_limiter!, thread) = cache
+    (; Aᵢ₁, Aᵢ₂, Aᵢ₃, Aᵢ₄, Bₗ, B̂ₗ, Bᵢ, B̂ᵢ, Cᵢ) = cache.tab
 
     @.. broadcast=false thread=thread fᵢ₋₂=zero(fsalfirst)
     @.. broadcast=false thread=thread fᵢ₋₃=zero(fsalfirst)
@@ -804,12 +819,12 @@ end
     #stages 1 to s-1
     for i in eachindex(Aᵢ₁)
         integrator.opts.adaptive &&
-            (@.. broadcast=false thread=thread tmp=tmp + (Bᵢ[i] - B̂ᵢ[i]) * dt * k)
-        @.. broadcast=false thread=thread gprev=uᵢ₋₄ +
-                                                (Aᵢ₁[i] * k + Aᵢ₂[i] * fᵢ₋₂ +
-                                                 Aᵢ₃[i] * fᵢ₋₃ +
-                                                 Aᵢ₄[i] * fᵢ₋₄) * dt
-        @.. broadcast=false thread=thread u=u + Bᵢ[i] * dt * k
+            (@.. broadcast=false thread=thread tmp=tmp+(Bᵢ[i]-B̂ᵢ[i])*dt*k)
+        @.. broadcast=false thread=thread gprev=uᵢ₋₄+
+        (Aᵢ₁[i]*k+Aᵢ₂[i]*fᵢ₋₂+
+         Aᵢ₃[i]*fᵢ₋₃+
+         Aᵢ₄[i]*fᵢ₋₄)*dt
+        @.. broadcast=false thread=thread u=u+Bᵢ[i]*dt*k
         @.. broadcast=false thread=thread fᵢ₋₄=fᵢ₋₃
         @.. broadcast=false thread=thread fᵢ₋₃=fᵢ₋₂
         @.. broadcast=false thread=thread fᵢ₋₂=k
@@ -823,8 +838,8 @@ end
 
     #last stage
     integrator.opts.adaptive &&
-        (@.. broadcast=false thread=thread tmp=tmp + (Bₗ - B̂ₗ) * dt * k)
-    @.. broadcast=false thread=thread u=u + Bₗ * dt * k
+        (@.. broadcast=false thread=thread tmp=tmp+(Bₗ-B̂ₗ)*dt*k)
+    @.. broadcast=false thread=thread u=u+Bₗ*dt*k
 
     step_limiter!(u, integrator, p, t + dt)
 
@@ -841,7 +856,7 @@ end
 end
 
 function initialize!(integrator, cache::RK46NLCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 1
     resize!(integrator.k, integrator.kshortsize)
@@ -851,38 +866,38 @@ function initialize!(integrator, cache::RK46NLCache)
 end
 
 @muladd function perform_step!(integrator, cache::RK46NLCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack α2, α3, α4, α5, α6, β1, β2, β3, β4, β5, β6, c2, c3, c4, c5, c6 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread) = cache
+    (; α2, α3, α4, α5, α6, β1, β2, β3, β4, β5, β6, c2, c3, c4, c5, c6) = cache.tab
 
     # u1
-    @.. broadcast=false thread=thread tmp=dt * fsalfirst
-    @.. broadcast=false thread=thread u=uprev + β1 * tmp
+    @.. broadcast=false thread=thread tmp=dt*fsalfirst
+    @.. broadcast=false thread=thread u=uprev+β1*tmp
     stage_limiter!(u, integrator, p, t + c2 * dt)
     # u2
     f(k, u, p, t + c2 * dt)
-    @.. broadcast=false thread=thread tmp=α2 * tmp + dt * k
-    @.. broadcast=false thread=thread u=u + β2 * tmp
+    @.. broadcast=false thread=thread tmp=α2*tmp+dt*k
+    @.. broadcast=false thread=thread u=u+β2*tmp
     stage_limiter!(u, integrator, p, t + c3 * dt)
     # u3
     f(k, u, p, t + c3 * dt)
-    @.. broadcast=false thread=thread tmp=α3 * tmp + dt * k
-    @.. broadcast=false thread=thread u=u + β3 * tmp
+    @.. broadcast=false thread=thread tmp=α3*tmp+dt*k
+    @.. broadcast=false thread=thread u=u+β3*tmp
     stage_limiter!(u, integrator, p, t + c4 * dt)
     # u4
     f(k, u, p, t + c4 * dt)
-    @.. broadcast=false thread=thread tmp=α4 * tmp + dt * k
-    @.. broadcast=false thread=thread u=u + β4 * tmp
+    @.. broadcast=false thread=thread tmp=α4*tmp+dt*k
+    @.. broadcast=false thread=thread u=u+β4*tmp
     stage_limiter!(u, integrator, p, t + c5 * dt)
     # u5 = u
     f(k, u, p, t + c5 * dt)
-    @.. broadcast=false thread=thread tmp=α5 * tmp + dt * k
-    @.. broadcast=false thread=thread u=u + β5 * tmp
+    @.. broadcast=false thread=thread tmp=α5*tmp+dt*k
+    @.. broadcast=false thread=thread u=u+β5*tmp
     stage_limiter!(u, integrator, p, t + c6 * dt)
 
     f(k, u, p, t + c6 * dt)
-    @.. broadcast=false thread=thread tmp=α6 * tmp + dt * k
-    @.. broadcast=false thread=thread u=u + β6 * tmp
+    @.. broadcast=false thread=thread tmp=α6*tmp+dt*k
+    @.. broadcast=false thread=thread u=u+β6*tmp
     stage_limiter!(u, integrator, p, t + dt)
     step_limiter!(u, integrator, p, t + dt)
 
@@ -902,8 +917,8 @@ function initialize!(integrator, cache::RK46NLConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::RK46NLConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack α2, α3, α4, α5, α6, β1, β2, β3, β4, β5, β6, c2, c3, c4, c5, c6 = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; α2, α3, α4, α5, α6, β1, β2, β3, β4, β5, β6, c2, c3, c4, c5, c6) = cache
 
     # u1
     tmp = dt * integrator.fsalfirst
@@ -944,8 +959,8 @@ end
 
 @muladd function perform_step!(integrator, cache::SHLDDRK52ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack α2, α3, α4, α5, β1, β2, β3, β4, β5, c2, c3, c4, c5 = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; α2, α3, α4, α5, β1, β2, β3, β4, β5, c2, c3, c4, c5) = cache
 
     # u1
     tmp = dt * integrator.fsalfirst
@@ -971,7 +986,7 @@ end
 end
 
 function initialize!(integrator, cache::SHLDDRK52Cache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 2
     resize!(integrator.k, integrator.kshortsize)
@@ -982,33 +997,33 @@ function initialize!(integrator, cache::SHLDDRK52Cache)
 end
 
 @muladd function perform_step!(integrator, cache::SHLDDRK52Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack α2, α3, α4, α5, β1, β2, β3, β4, β5, c2, c3, c4, c5 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread) = cache
+    (; α2, α3, α4, α5, β1, β2, β3, β4, β5, c2, c3, c4, c5) = cache.tab
 
     # u1
-    @.. thread=thread tmp=dt * fsalfirst
-    @.. thread=thread u=uprev + β1 * tmp
+    @.. thread=thread tmp=dt*fsalfirst
+    @.. thread=thread u=uprev+β1*tmp
     stage_limiter!(u, integrator, p, t + c2 * dt)
     # u2
     f(k, u, p, t + c2 * dt)
-    @.. thread=thread tmp=α2 * tmp + dt * k
-    @.. thread=thread u=u + β2 * tmp
+    @.. thread=thread tmp=α2*tmp+dt*k
+    @.. thread=thread u=u+β2*tmp
     stage_limiter!(u, integrator, p, t + c3 * dt)
     # u3
     f(k, u, p, t + c3 * dt)
-    @.. thread=thread tmp=α3 * tmp + dt * k
-    @.. thread=thread u=u + β3 * tmp
+    @.. thread=thread tmp=α3*tmp+dt*k
+    @.. thread=thread u=u+β3*tmp
     stage_limiter!(u, integrator, p, t + c4 * dt)
     # u4
     f(k, u, p, t + c4 * dt)
-    @.. thread=thread tmp=α4 * tmp + dt * k
-    @.. thread=thread u=u + β4 * tmp
+    @.. thread=thread tmp=α4*tmp+dt*k
+    @.. thread=thread u=u+β4*tmp
     stage_limiter!(u, integrator, p, t + c5 * dt)
     # u5 = u
     f(k, u, p, t + c5 * dt)
-    @.. thread=thread tmp=α5 * tmp + dt * k
-    @.. thread=thread u=u + β5 * tmp
+    @.. thread=thread tmp=α5*tmp+dt*k
+    @.. thread=thread u=u+β5*tmp
     stage_limiter!(u, integrator, p, t + dt)
     step_limiter!(u, integrator, p, t + dt)
 
@@ -1030,8 +1045,9 @@ end
 
 @muladd function perform_step!(integrator, cache::SHLDDRK_2NConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack α21, α31, α41, α51, β11, β21, β31, β41, β51, c21, c31, c41, c51, α22, α32, α42, α52, α62, β12, β22, β32, β42, β52, β62, c22, c32, c42, c52, c62 = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; α21, α31, α41, α51, β11, β21, β31, β41, β51, c21, c31, c41, c51, α22, α32,
+        α42, α52, α62, β12, β22, β32, β42, β52, β62, c22, c32, c42, c52, c62) = cache
 
     if integrator.u_modified
         cache.step = 1
@@ -1086,7 +1102,7 @@ end
 end
 
 function initialize!(integrator, cache::SHLDDRK_2NCache)
-    @unpack k, fsalfirst = cache
+    (; k, fsalfirst) = cache
 
     integrator.kshortsize = 2
     resize!(integrator.k, integrator.kshortsize)
@@ -1097,9 +1113,10 @@ function initialize!(integrator, cache::SHLDDRK_2NCache)
 end
 
 @muladd function perform_step!(integrator, cache::SHLDDRK_2NCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread = cache
-    @unpack α21, α31, α41, α51, β11, β21, β31, β41, β51, c21, c31, c41, c51, α22, α32, α42, α52, α62, β12, β22, β32, β42, β52, β62, c22, c32, c42, c52, c62 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; k, fsalfirst, tmp, stage_limiter!, step_limiter!, thread) = cache
+    (; α21, α31, α41, α51, β11, β21, β31, β41, β51, c21, c31, c41, c51, α22, α32, α42,
+        α52, α62, β12, β22, β32, β42, β52, β62, c22, c32, c42, c52, c62) = cache.tab
 
     if integrator.u_modified
         cache.step = 1
@@ -1107,28 +1124,28 @@ end
 
     if cache.step % 2 == 1
         # u1
-        @.. thread=thread tmp=dt * fsalfirst
-        @.. thread=thread u=uprev + β11 * tmp
+        @.. thread=thread tmp=dt*fsalfirst
+        @.. thread=thread u=uprev+β11*tmp
         stage_limiter!(u, integrator, p, t + c21 * dt)
         # u2
         f(k, u, p, t + c21 * dt)
-        @.. thread=thread tmp=α21 * tmp + dt * k
-        @.. thread=thread u=u + β21 * tmp
+        @.. thread=thread tmp=α21*tmp+dt*k
+        @.. thread=thread u=u+β21*tmp
         stage_limiter!(u, integrator, p, t + c31 * dt)
         # u3
         f(k, u, p, t + c31 * dt)
-        @.. thread=thread tmp=α31 * tmp + dt * k
-        @.. thread=thread u=u + β31 * tmp
+        @.. thread=thread tmp=α31*tmp+dt*k
+        @.. thread=thread u=u+β31*tmp
         stage_limiter!(u, integrator, p, t + c41 * dt)
         # u4
         f(k, u, p, t + c41 * dt)
-        @.. thread=thread tmp=α41 * tmp + dt * k
-        @.. thread=thread u=u + β41 * tmp
+        @.. thread=thread tmp=α41*tmp+dt*k
+        @.. thread=thread u=u+β41*tmp
         stage_limiter!(u, integrator, p, t + c51 * dt)
         # u5 = u
         f(k, u, p, t + c51 * dt)
-        @.. thread=thread tmp=α51 * tmp + dt * k
-        @.. thread=thread u=u + β51 * tmp
+        @.. thread=thread tmp=α51*tmp+dt*k
+        @.. thread=thread u=u+β51*tmp
         stage_limiter!(u, integrator, p, t + dt)
         step_limiter!(u, integrator, p, t + dt)
 
@@ -1136,33 +1153,33 @@ end
         OrdinaryDiffEqCore.increment_nf!(integrator.stats, 5)
     else
         # u1
-        @.. thread=thread tmp=dt * fsalfirst
-        @.. thread=thread u=uprev + β12 * tmp
+        @.. thread=thread tmp=dt*fsalfirst
+        @.. thread=thread u=uprev+β12*tmp
         stage_limiter!(u, integrator, p, t + c22 * dt)
         # u2
         f(k, u, p, t + c22 * dt)
-        @.. thread=thread tmp=α22 * tmp + dt * k
-        @.. thread=thread u=u + β22 * tmp
+        @.. thread=thread tmp=α22*tmp+dt*k
+        @.. thread=thread u=u+β22*tmp
         stage_limiter!(u, integrator, p, t + c32 * dt)
         # u3
         f(k, u, p, t + c32 * dt)
-        @.. thread=thread tmp=α32 * tmp + dt * k
-        @.. thread=thread u=u + β32 * tmp
+        @.. thread=thread tmp=α32*tmp+dt*k
+        @.. thread=thread u=u+β32*tmp
         stage_limiter!(u, integrator, p, t + c42 * dt)
         # u4
         f(k, u, p, t + c42 * dt)
-        @.. thread=thread tmp=α42 * tmp + dt * k
-        @.. thread=thread u=u + β42 * tmp
+        @.. thread=thread tmp=α42*tmp+dt*k
+        @.. thread=thread u=u+β42*tmp
         stage_limiter!(u, integrator, p, t + c52 * dt)
         # u5 = u
         f(k, u, p, t + c52 * dt)
-        @.. thread=thread tmp=α52 * tmp + dt * k
-        @.. thread=thread u=u + β52 * tmp
+        @.. thread=thread tmp=α52*tmp+dt*k
+        @.. thread=thread u=u+β52*tmp
         stage_limiter!(u, integrator, p, t + c62 * dt)
         # u6 = u
         f(k, u, p, t + c62 * dt)
-        @.. thread=thread tmp=α62 * tmp + dt * k
-        @.. thread=thread u=u + β62 * tmp
+        @.. thread=thread tmp=α62*tmp+dt*k
+        @.. thread=thread u=u+β62*tmp
         stage_limiter!(u, integrator, p, t + dt)
         step_limiter!(u, integrator, p, t + dt)
 
